"""
@WELL MCP Bindings - Multi-platform file care tools.

Provides MCP/tool bindings for @WELL file care operations across:
- Claude MCP (mcp_claude.py)
- GitHub Copilot (copilot_github.py)
- ChatGPT Codex (chatgpt_codex.py)
- Google Gemini CLI (gemini_cli.py)

Core Logic: arifos_core.integration.waw.well_file_care

Version: v42.0.0 (migrated from L4_MCP)
"""

__all__ = ["mcp_claude", "copilot_github", "chatgpt_codex", "gemini_cli"]
